"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleObjectType = void 0;
const parseSchema_1 = require("./parseSchema");
const toPascalCase_1 = require("./toPascalCase");
const handleObjectType = function ({ path, schema, direction }) {
    var _a;
    const graphqlTypeName = (0, toPascalCase_1.toPascalCase)(path);
    const graphqlTypeDefinitions = [];
    const lines = [];
    for (const [propertyName, propertySchema] of Object.entries(schema.properties)) {
        const isRequired = (_a = (schema.required && schema.required.includes(propertyName))) !== null && _a !== void 0 ? _a : false;
        const { typeName: propertyGraphqlTypeName, typeDefinitions: propertyGraphqlTypeDefinitions } = (0, parseSchema_1.parseSchema)({
            path: [...path, propertyName],
            schema: propertySchema,
            direction
        });
        let line = `  ${propertyName}: ${propertyGraphqlTypeName}`;
        line += isRequired ? '!\n' : '\n';
        lines.push(line);
        graphqlTypeDefinitions.push(...propertyGraphqlTypeDefinitions);
    }
    let currentGraphqlTypeDefinition = '';
    currentGraphqlTypeDefinition += direction === 'input' ? 'input' : 'type';
    if (lines.length > 0) {
        currentGraphqlTypeDefinition += ` ${graphqlTypeName} {\n`;
        for (const line of lines) {
            currentGraphqlTypeDefinition += line;
        }
        currentGraphqlTypeDefinition += '}';
    }
    else {
        currentGraphqlTypeDefinition += ` ${graphqlTypeName}`;
    }
    graphqlTypeDefinitions.push(currentGraphqlTypeDefinition);
    return {
        typeName: graphqlTypeName,
        typeDefinitions: graphqlTypeDefinitions
    };
};
exports.handleObjectType = handleObjectType;
